package com.kgraph.graph.service;

import java.util.List;
import java.util.Map;

import com.kgraph.graph.domain.SourceFile;

/**
 * 源文件管理Service接口
 * 
 * @author Allen
 * @date 2023-10-16
 */
public interface ISourceFileService 
{
    /**
     * 查询源文件管理
     * 
     * @param id 源文件管理主键
     * @return 源文件管理
     */
    public SourceFile selectSourceFileById(Long id);

    /**
     * 查询源文件管理列表
     * 
     * @param sourceFile 源文件管理
     * @return 源文件管理集合
     */
    public List<SourceFile> selectSourceFileList(SourceFile sourceFile);

    /**
     * 新增源文件管理
     * 
     * @param sourceFile 源文件管理
     * @return 结果
     */
    public int insertSourceFile(SourceFile sourceFile);

    /**
     * 修改源文件管理
     * 
     * @param sourceFile 源文件管理
     * @return 结果
     */
    public int updateSourceFile(SourceFile sourceFile);

    /**
     * 批量删除源文件管理
     * 
     * @param ids 需要删除的源文件管理主键集合
     * @return 结果
     */
    public int deleteSourceFileByIds(Long[] ids);

    /**
     * 删除源文件管理信息
     * 
     * @param id 源文件管理主键
     * @return 结果
     */
    public int deleteSourceFileById(Long id);

    List getOptions();
}
